@@ -21,7 +21,7 @@ typedef Eo Efl_Player;
  */
 #define EFL_PLAYER_INTERFACE efl_player_interface_get()
 
-EWAPI const Efl_Class *efl_player_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_player_interface_get(void) EINA_CONST;
 
 /**
  * @brief Playback state of the media file.
@@ -47,7 +47,7 @@ EWAPI const Efl_Class *efl_player_interface_get(void);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_playing_set(Eo *obj, Eina_Bool playing);
+EAPI EAPI_WEAK Eina_Bool efl_player_playing_set(Eo *obj, Eina_Bool playing);
 
 /**
  * @brief Playback state of the media file.
@@ -72,7 +72,7 @@ EOAPI Eina_Bool efl_player_playing_set(Eo *obj, Eina_Bool playing);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_playing_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_player_playing_get(const Eo *obj);
 
 /**
  * @brief Pause state of the media file.
@@ -94,7 +94,7 @@ EOAPI Eina_Bool efl_player_playing_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_paused_set(Eo *obj, Eina_Bool paused);
+EAPI EAPI_WEAK Eina_Bool efl_player_paused_set(Eo *obj, Eina_Bool paused);
 
 /**
  * @brief Pause state of the media file.
@@ -115,7 +115,7 @@ EOAPI Eina_Bool efl_player_paused_set(Eo *obj, Eina_Bool paused);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_paused_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_player_paused_get(const Eo *obj);
 
 /**
  * @brief Position in the media file.
@@ -132,7 +132,7 @@ EOAPI Eina_Bool efl_player_paused_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_playback_position_set(Eo *obj, double sec);
+EAPI EAPI_WEAK void efl_player_playback_position_set(Eo *obj, double sec);
 
 /**
  * @brief Position in the media file.
@@ -150,7 +150,7 @@ EOAPI void efl_player_playback_position_set(Eo *obj, double sec);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_playback_position_get(const Eo *obj);
+EAPI EAPI_WEAK double efl_player_playback_position_get(const Eo *obj);
 
 /**
  * @brief How much of the file has been played.
@@ -165,7 +165,7 @@ EOAPI double efl_player_playback_position_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_playback_progress_set(Eo *obj, double progress);
+EAPI EAPI_WEAK void efl_player_playback_progress_set(Eo *obj, double progress);
 
 /**
  * @brief How much of the file has been played.
@@ -181,7 +181,7 @@ EOAPI void efl_player_playback_progress_set(Eo *obj, double progress);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_playback_progress_get(const Eo *obj);
+EAPI EAPI_WEAK double efl_player_playback_progress_get(const Eo *obj);
 
 /**
  * @brief Control the playback speed of the media file.
@@ -196,7 +196,7 @@ EOAPI double efl_player_playback_progress_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_playback_speed_set(Eo *obj, double speed);
+EAPI EAPI_WEAK void efl_player_playback_speed_set(Eo *obj, double speed);
 
 /**
  * @brief Control the playback speed of the media file.
@@ -212,7 +212,7 @@ EOAPI void efl_player_playback_speed_set(Eo *obj, double speed);
  *
  * @ingroup Efl_Player
  */
-EOAPI double efl_player_playback_speed_get(const Eo *obj);
+EAPI EAPI_WEAK double efl_player_playback_speed_get(const Eo *obj);
 
 /**
  * @brief When @c true, playback will start as soon as the media is ready.
@@ -234,7 +234,7 @@ EOAPI double efl_player_playback_speed_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_autoplay_set(Eo *obj, Eina_Bool autoplay);
+EAPI EAPI_WEAK void efl_player_autoplay_set(Eo *obj, Eina_Bool autoplay);
 
 /**
  * @brief When @c true, playback will start as soon as the media is ready.
@@ -257,7 +257,7 @@ EOAPI void efl_player_autoplay_set(Eo *obj, Eina_Bool autoplay);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_autoplay_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_player_autoplay_get(const Eo *obj);
 
 /**
  * @brief Enable playback looping.
@@ -274,7 +274,7 @@ EOAPI Eina_Bool efl_player_autoplay_get(const Eo *obj);
  *
  * @ingroup Efl_Player
  */
-EOAPI void efl_player_playback_loop_set(Eo *obj, Eina_Bool looping);
+EAPI EAPI_WEAK void efl_player_playback_loop_set(Eo *obj, Eina_Bool looping);
 
 /**
  * @brief Enable playback looping.
@@ -292,9 +292,9 @@ EOAPI void efl_player_playback_loop_set(Eo *obj, Eina_Bool looping);
  *
  * @ingroup Efl_Player
  */
-EOAPI Eina_Bool efl_player_playback_loop_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_player_playback_loop_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYING_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYING_CHANGED;
 
 /** Called when the playing state has changed. The event value reflects the
  * current state.
@@ -306,7 +306,7 @@ EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYING_CHANGED;
  */
 #define EFL_PLAYER_EVENT_PLAYING_CHANGED (&(_EFL_PLAYER_EVENT_PLAYING_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PAUSED_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PAUSED_CHANGED;
 
 /** Called when the paused state has changed. The event value reflects the
  * current state.
@@ -318,7 +318,7 @@ EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PAUSED_CHANGED;
  */
 #define EFL_PLAYER_EVENT_PAUSED_CHANGED (&(_EFL_PLAYER_EVENT_PAUSED_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_PROGRESS_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_PROGRESS_CHANGED;
 
 /** Called when the playback_progress state has changed. The event value
  * reflects the current state.
@@ -330,7 +330,7 @@ EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_PROGRESS_CHA
  */
 #define EFL_PLAYER_EVENT_PLAYBACK_PROGRESS_CHANGED (&(_EFL_PLAYER_EVENT_PLAYBACK_PROGRESS_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_POSITION_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_POSITION_CHANGED;
 
 /** Called when the playback_position state has changed. The event value
  * reflects the current state.
@@ -342,7 +342,7 @@ EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_POSITION_CHA
  */
 #define EFL_PLAYER_EVENT_PLAYBACK_POSITION_CHANGED (&(_EFL_PLAYER_EVENT_PLAYBACK_POSITION_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_REPEATED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_REPEATED;
 
 /** Called when the player has begun to repeat its data stream. The event value
  * is the current number of repeats.
@@ -354,7 +354,7 @@ EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_REPEATED;
  */
 #define EFL_PLAYER_EVENT_PLAYBACK_REPEATED (&(_EFL_PLAYER_EVENT_PLAYBACK_REPEATED))
 
-EWAPI extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_FINISHED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_PLAYER_EVENT_PLAYBACK_FINISHED;
 
 /** Called when the player has completed playing its data stream.
  *
