@@ -68,7 +68,7 @@ typedef struct _Efl_Ui_Focus_Manager_Logical_End_Detail
  */
 #define EFL_UI_FOCUS_MANAGER_INTERFACE efl_ui_focus_manager_interface_get()
 
-EWAPI const Efl_Class *efl_ui_focus_manager_interface_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_focus_manager_interface_get(void) EINA_CONST;
 
 /**
  * @brief Moves the focus in the given direction to the next regular widget.
@@ -85,7 +85,7 @@ EWAPI const Efl_Class *efl_ui_focus_manager_interface_get(void);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_move(Eo *obj, Efl_Ui_Focus_Direction direction);
+EAPI EAPI_WEAK Efl_Ui_Focus_Object *efl_ui_focus_manager_move(Eo *obj, Efl_Ui_Focus_Direction direction);
 
 /**
  * @brief Returns the object in the @c direction from @c child.
@@ -104,7 +104,7 @@ EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_move(Eo *obj, Efl_Ui_Focus_Direc
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_request_move(Eo *obj, Efl_Ui_Focus_Direction direction, Efl_Ui_Focus_Object *child, Eina_Bool logical);
+EAPI EAPI_WEAK Efl_Ui_Focus_Object *efl_ui_focus_manager_request_move(Eo *obj, Efl_Ui_Focus_Direction direction, Efl_Ui_Focus_Object *child, Eina_Bool logical);
 
 /**
  * @brief The element which is currently focused by this manager.
@@ -121,7 +121,7 @@ EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_request_move(Eo *obj, Efl_Ui_Foc
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_focus_set(Eo *obj, Efl_Ui_Focus_Object *focus);
+EAPI EAPI_WEAK void efl_ui_focus_manager_focus_set(Eo *obj, Efl_Ui_Focus_Object *focus);
 
 /**
  * @brief The element which is currently focused by this manager.
@@ -139,7 +139,7 @@ EOAPI void efl_ui_focus_manager_focus_set(Eo *obj, Efl_Ui_Focus_Object *focus);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_focus_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Focus_Object *efl_ui_focus_manager_focus_get(const Eo *obj);
 
 /**
  * @brief Add another manager to serve the move requests.
@@ -154,7 +154,7 @@ EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_focus_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_redirect_set(Eo *obj, Efl_Ui_Focus_Manager *redirect);
+EAPI EAPI_WEAK void efl_ui_focus_manager_redirect_set(Eo *obj, Efl_Ui_Focus_Manager *redirect);
 
 /**
  * @brief Add another manager to serve the move requests.
@@ -170,7 +170,7 @@ EOAPI void efl_ui_focus_manager_redirect_set(Eo *obj, Efl_Ui_Focus_Manager *redi
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Manager *efl_ui_focus_manager_redirect_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Focus_Manager *efl_ui_focus_manager_redirect_get(const Eo *obj);
 
 /**
  * @brief Elements which are at the border of the graph.
@@ -186,7 +186,21 @@ EOAPI Efl_Ui_Focus_Manager *efl_ui_focus_manager_redirect_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Eina_Iterator *efl_ui_focus_manager_border_elements_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK Eina_Iterator *efl_ui_focus_manager_border_elements_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+
+/**
+ * @brief Return @c true if the border elements have changed since the last
+ * invocation of @ref efl_ui_focus_manager_border_elements_get
+ *
+ * @param[in] obj The object.
+ *
+ * @return @c true if there was a change, @c false if not
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Ui_Focus_Manager
+ */
+EAPI EAPI_WEAK Eina_Bool efl_ui_focus_manager_border_elements_changed_get(const Eo *obj);
 
 /**
  * @brief Elements that are at the border of the viewport
@@ -203,7 +217,7 @@ EOAPI Eina_Iterator *efl_ui_focus_manager_border_elements_get(const Eo *obj) EFL
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Eina_Iterator *efl_ui_focus_manager_viewport_elements_get(const Eo *obj, Eina_Rect viewport) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK Eina_Iterator *efl_ui_focus_manager_viewport_elements_get(const Eo *obj, Eina_Rect viewport) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Root node for all logical sub-trees.
@@ -219,7 +233,7 @@ EOAPI Eina_Iterator *efl_ui_focus_manager_viewport_elements_get(const Eo *obj, E
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Eina_Bool efl_ui_focus_manager_root_set(Eo *obj, Efl_Ui_Focus_Object *root);
+EAPI EAPI_WEAK Eina_Bool efl_ui_focus_manager_root_set(Eo *obj, Efl_Ui_Focus_Object *root);
 
 /**
  * @brief Root node for all logical sub-trees.
@@ -234,7 +248,7 @@ EOAPI Eina_Bool efl_ui_focus_manager_root_set(Eo *obj, Efl_Ui_Focus_Object *root
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_root_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Focus_Object *efl_ui_focus_manager_root_get(const Eo *obj);
 
 /**
  * @brief Returns the widget in the direction next.
@@ -252,7 +266,7 @@ EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_root_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_request_subchild(Eo *obj, Efl_Ui_Focus_Object *root);
+EAPI EAPI_WEAK Efl_Ui_Focus_Object *efl_ui_focus_manager_request_subchild(Eo *obj, Efl_Ui_Focus_Object *root);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -269,7 +283,7 @@ EOAPI Efl_Ui_Focus_Object *efl_ui_focus_manager_request_subchild(Eo *obj, Efl_Ui
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Relations *efl_ui_focus_manager_fetch(Eo *obj, Efl_Ui_Focus_Object *child) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+EAPI EAPI_WEAK Efl_Ui_Focus_Relations *efl_ui_focus_manager_fetch(Eo *obj, Efl_Ui_Focus_Object *child) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -286,7 +300,7 @@ EOAPI Efl_Ui_Focus_Relations *efl_ui_focus_manager_fetch(Eo *obj, Efl_Ui_Focus_O
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI Efl_Ui_Focus_Manager_Logical_End_Detail efl_ui_focus_manager_logical_end(Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Focus_Manager_Logical_End_Detail efl_ui_focus_manager_logical_end(Eo *obj);
 
 /**
  * @brief Resets the history stack of this manager object. This means the
@@ -302,7 +316,7 @@ EOAPI Efl_Ui_Focus_Manager_Logical_End_Detail efl_ui_focus_manager_logical_end(E
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_reset_history(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_focus_manager_reset_history(Eo *obj);
 
 /**
  * @brief Removes the uppermost history element, and focuses the previous one.
@@ -316,7 +330,7 @@ EOAPI void efl_ui_focus_manager_reset_history(Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_pop_history_stack(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_focus_manager_pop_history_stack(Eo *obj);
 
 /**
  * @brief Called when this manager is set as redirect.
@@ -333,7 +347,7 @@ EOAPI void efl_ui_focus_manager_pop_history_stack(Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_setup_on_first_touch(Eo *obj, Efl_Ui_Focus_Direction direction, Efl_Ui_Focus_Object *entry);
+EAPI EAPI_WEAK void efl_ui_focus_manager_setup_on_first_touch(Eo *obj, Efl_Ui_Focus_Direction direction, Efl_Ui_Focus_Object *entry);
 
 /**
  * @brief Disables the cache invalidation when an object is moved.
@@ -351,7 +365,7 @@ EOAPI void efl_ui_focus_manager_setup_on_first_touch(Eo *obj, Efl_Ui_Focus_Direc
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_dirty_logic_freeze(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_focus_manager_dirty_logic_freeze(Eo *obj);
 
 /**
  * @brief Enables the cache invalidation when an object is moved.
@@ -364,9 +378,9 @@ EOAPI void efl_ui_focus_manager_dirty_logic_freeze(Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Manager
  */
-EOAPI void efl_ui_focus_manager_dirty_logic_unfreeze(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_focus_manager_dirty_logic_unfreeze(Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_REDIRECT_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_REDIRECT_CHANGED;
 
 /** Redirect object has changed, the old manager is passed as an event
  * argument.
@@ -378,7 +392,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_REDIRECT_CH
  */
 #define EFL_UI_FOCUS_MANAGER_EVENT_REDIRECT_CHANGED (&(_EFL_UI_FOCUS_MANAGER_EVENT_REDIRECT_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_FLUSH_PRE;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_FLUSH_PRE;
 
 /** After this event, the manager object will calculate relations in the graph.
  * Can be used to add / remove children in a lazy fashion.
@@ -389,7 +403,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_FLUSH_PRE;
  */
 #define EFL_UI_FOCUS_MANAGER_EVENT_FLUSH_PRE (&(_EFL_UI_FOCUS_MANAGER_EVENT_FLUSH_PRE))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_COORDS_DIRTY;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_COORDS_DIRTY;
 
 /** Cached relationship calculation results have been invalidated.
  *
@@ -399,7 +413,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_COORDS_DIRT
  */
 #define EFL_UI_FOCUS_MANAGER_EVENT_COORDS_DIRTY (&(_EFL_UI_FOCUS_MANAGER_EVENT_COORDS_DIRTY))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_MANAGER_FOCUS_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_MANAGER_FOCUS_CHANGED;
 
 /** The manager_focus property has changed. The previously focused object is
  * passed as an event argument.
@@ -411,7 +425,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_MANAGER_FOC
  */
 #define EFL_UI_FOCUS_MANAGER_EVENT_MANAGER_FOCUS_CHANGED (&(_EFL_UI_FOCUS_MANAGER_EVENT_MANAGER_FOCUS_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_DIRTY_LOGIC_FREEZE_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_FOCUS_MANAGER_EVENT_DIRTY_LOGIC_FREEZE_CHANGED;
 
 /** Called when this focus manager is frozen or thawed, even_info being @c true
  * indicates that it is now frozen, @c false indicates that it is thawed.
