@@ -14,11 +14,13 @@ typedef Eo Efl_Ui_Layout_Part;
 
 #endif
 /** Elementary layout internal part class
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Layout_Part
  */
 #define EFL_UI_LAYOUT_PART_CLASS efl_ui_layout_part_class_get()
 
-EWAPI const Efl_Class *efl_ui_layout_part_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_layout_part_class_get(void) EINA_CONST;
 
 #endif
