@@ -20,7 +20,7 @@ typedef Eo Efl_Ui_Win;
  *
  * Currently, only the X11 backed engines use them.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Type
  */
 typedef enum
 {
@@ -74,7 +74,7 @@ typedef enum
  * When the application window is being managed by Illume it may request any of
  * the following layouts for the virtual keyboard.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Keyboard_Mode
  */
 typedef enum
 {
@@ -101,36 +101,43 @@ typedef enum
  *
  * @since 1.22
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Indicator_Mode
  */
 typedef enum
 {
   EFL_UI_WIN_INDICATOR_MODE_OFF = 0, /**< Request to deactivate the indicator.
-                                      */
+                                      *
+                                      * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_BG_OPAQUE, /**< The indicator icon is opaque, as is
                                         * the indicator background. The content
                                         * of window is located at the end of
                                         * the indicator. The area of indicator
                                         * and window content are not
-                                        * overlapped. */
+                                        * overlapped.
+                                        *
+                                        * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_BG_TRANSPARENT, /**< The icon of indicator is
                                              * opaque, but the background is
                                              * transparent. The content of
                                              * window is located under the
                                              * indicator in Z-order. The area
                                              * of indicator and window content
-                                             * are overlapped. */
+                                             * are overlapped.
+                                             *
+                                             * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_HIDDEN /**< The indicator is hidden so user can see
                                     * only the content of window such as in
                                     * video mode. If user flicks the upper side
                                     * of window, the indicator is shown
-                                    * temporarily. */
+                                    * temporarily.
+                                    *
+                                    * @since 1.22 */
 } Efl_Ui_Win_Indicator_Mode;
 
 #ifdef EFL_BETA_API_SUPPORT
 /** Defines the mode of a modal window.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Modal_Mode
  */
 typedef enum
 {
@@ -142,7 +149,7 @@ typedef enum
 #ifdef EFL_BETA_API_SUPPORT
 /** Defines the mode of a urgent window.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Urgent_Mode
  */
 typedef enum
 {
@@ -164,20 +171,29 @@ typedef enum
  *
  * @since 1.22
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Move_Resize_Mode
  */
 typedef enum
 {
-  EFL_UI_WIN_MOVE_RESIZE_MODE_MOVE = 1, /**< Start moving window */
+  EFL_UI_WIN_MOVE_RESIZE_MODE_MOVE = 1, /**< Start moving window
+                                         *
+                                         * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_TOP = 2 /* 1 >> 1 */, /**< Start resizing window
-                                                     * to the top */
+                                                     * to the top
+                                                     *
+                                                     * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_BOTTOM = 4 /* 1 >> 2 */, /**< Start resizing
                                                         * window to the bottom
-                                                        */
+                                                        *
+                                                        * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_LEFT = 8 /* 1 >> 3 */, /**< Start resizing window
-                                                      * to the left */
+                                                      * to the left
+                                                      *
+                                                      * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_RIGHT = 16 /* 1 >> 4 */ /**< Start resizing window
-                                                       * to the right */
+                                                       * to the right
+                                                       *
+                                                       * @since 1.22 */
 } Efl_Ui_Win_Move_Resize_Mode;
 
 
@@ -190,7 +206,7 @@ typedef enum
  */
 #define EFL_UI_WIN_CLASS efl_ui_win_class_get()
 
-EWAPI const Efl_Class *efl_ui_win_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_win_class_get(void) EINA_CONST;
 
 /**
  * @brief In some environments you may have an indicator that shows battery
@@ -209,7 +225,7 @@ EWAPI const Efl_Class *efl_ui_win_class_get(void);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_indicator_mode_set(Eo *obj, Efl_Ui_Win_Indicator_Mode type);
+EAPI EAPI_WEAK void efl_ui_win_indicator_mode_set(Eo *obj, Efl_Ui_Win_Indicator_Mode type);
 
 /**
  * @brief In some environments you may have an indicator that shows battery
@@ -229,7 +245,7 @@ EOAPI void efl_ui_win_indicator_mode_set(Eo *obj, Efl_Ui_Win_Indicator_Mode type
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Efl_Ui_Win_Indicator_Mode efl_ui_win_indicator_mode_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Win_Indicator_Mode efl_ui_win_indicator_mode_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -242,7 +258,7 @@ EOAPI Efl_Ui_Win_Indicator_Mode efl_ui_win_indicator_mode_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_keyboard_mode_set(Eo *obj, Efl_Ui_Win_Keyboard_Mode mode);
+EAPI EAPI_WEAK void efl_ui_win_keyboard_mode_set(Eo *obj, Efl_Ui_Win_Keyboard_Mode mode);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -257,7 +273,7 @@ EOAPI void efl_ui_win_keyboard_mode_set(Eo *obj, Efl_Ui_Win_Keyboard_Mode mode);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Efl_Ui_Win_Keyboard_Mode efl_ui_win_keyboard_mode_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Win_Keyboard_Mode efl_ui_win_keyboard_mode_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -277,7 +293,7 @@ EOAPI Efl_Ui_Win_Keyboard_Mode efl_ui_win_keyboard_mode_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_wm_available_rotations_set(Eo *obj, Eina_Bool allow_0, Eina_Bool allow_90, Eina_Bool allow_180, Eina_Bool allow_270);
+EAPI EAPI_WEAK void efl_ui_win_wm_available_rotations_set(Eo *obj, Eina_Bool allow_0, Eina_Bool allow_90, Eina_Bool allow_180, Eina_Bool allow_270);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -299,7 +315,7 @@ EOAPI void efl_ui_win_wm_available_rotations_set(Eo *obj, Eina_Bool allow_0, Ein
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_wm_available_rotations_get(const Eo *obj, Eina_Bool *allow_0, Eina_Bool *allow_90, Eina_Bool *allow_180, Eina_Bool *allow_270);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_wm_available_rotations_get(const Eo *obj, Eina_Bool *allow_0, Eina_Bool *allow_90, Eina_Bool *allow_180, Eina_Bool *allow_270);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -313,7 +329,7 @@ EOAPI Eina_Bool efl_ui_win_wm_available_rotations_get(const Eo *obj, Eina_Bool *
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_wm_available_profiles_set(Eo *obj, const Eina_Array *profiles);
+EAPI EAPI_WEAK void efl_ui_win_wm_available_profiles_set(Eo *obj, const Eina_Array *profiles);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -328,7 +344,7 @@ EOAPI void efl_ui_win_wm_available_profiles_set(Eo *obj, const Eina_Array *profi
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const Eina_Array *efl_ui_win_wm_available_profiles_get(const Eo *obj);
+EAPI EAPI_WEAK const Eina_Array *efl_ui_win_wm_available_profiles_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -346,7 +362,7 @@ EOAPI const Eina_Array *efl_ui_win_wm_available_profiles_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_screen_constrain_set(Eo *obj, Eina_Bool constrain);
+EAPI EAPI_WEAK void efl_ui_win_screen_constrain_set(Eo *obj, Eina_Bool constrain);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -365,7 +381,7 @@ EOAPI void efl_ui_win_screen_constrain_set(Eo *obj, Eina_Bool constrain);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_screen_constrain_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_screen_constrain_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -391,7 +407,7 @@ EOAPI Eina_Bool efl_ui_win_screen_constrain_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_prop_focus_skip_set(Eo *obj, Eina_Bool skip);
+EAPI EAPI_WEAK void efl_ui_win_prop_focus_skip_set(Eo *obj, Eina_Bool skip);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -423,7 +439,7 @@ EOAPI void efl_ui_win_prop_focus_skip_set(Eo *obj, Eina_Bool skip);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_autohide_set(Eo *obj, Eina_Bool autohide);
+EAPI EAPI_WEAK void efl_ui_win_autohide_set(Eo *obj, Eina_Bool autohide);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -455,7 +471,7 @@ EOAPI void efl_ui_win_autohide_set(Eo *obj, Eina_Bool autohide);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_autohide_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_autohide_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -477,7 +493,7 @@ EOAPI Eina_Bool efl_ui_win_autohide_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_exit_on_close_set(Eo *obj, const Eina_Value *exit_code);
+EAPI EAPI_WEAK void efl_ui_win_exit_on_close_set(Eo *obj, const Eina_Value *exit_code);
 
 /**
  * @brief Enable quitting the main loop when this window is closed.
@@ -499,7 +515,7 @@ EOAPI void efl_ui_win_exit_on_close_set(Eo *obj, const Eina_Value *exit_code);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const Eina_Value *efl_ui_win_exit_on_close_get(const Eo *obj);
+EAPI EAPI_WEAK const Eina_Value *efl_ui_win_exit_on_close_get(const Eo *obj);
 
 /**
  * @brief A window object's icon.
@@ -519,7 +535,7 @@ EOAPI const Eina_Value *efl_ui_win_exit_on_close_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_icon_object_set(Eo *obj, Efl_Canvas_Object *icon);
+EAPI EAPI_WEAK void efl_ui_win_icon_object_set(Eo *obj, Efl_Canvas_Object *icon);
 
 /**
  * @brief A window object's icon.
@@ -540,7 +556,7 @@ EOAPI void efl_ui_win_icon_object_set(Eo *obj, Efl_Canvas_Object *icon);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
+EAPI EAPI_WEAK const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
 
 /**
  * @brief The minimized state of a window.
@@ -552,7 +568,7 @@ EOAPI const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_minimized_set(Eo *obj, Eina_Bool state);
+EAPI EAPI_WEAK void efl_ui_win_minimized_set(Eo *obj, Eina_Bool state);
 
 /**
  * @brief The minimized state of a window.
@@ -565,7 +581,7 @@ EOAPI void efl_ui_win_minimized_set(Eo *obj, Eina_Bool state);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_minimized_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_minimized_get(const Eo *obj);
 
 /**
  * @brief The maximized state of a window.
@@ -577,7 +593,7 @@ EOAPI Eina_Bool efl_ui_win_minimized_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
+EAPI EAPI_WEAK void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
 
 /**
  * @brief The maximized state of a window.
@@ -590,7 +606,7 @@ EOAPI void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_maximized_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_maximized_get(const Eo *obj);
 
 /**
  * @brief The fullscreen state of a window.
@@ -602,7 +618,7 @@ EOAPI Eina_Bool efl_ui_win_maximized_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_fullscreen_set(Eo *obj, Eina_Bool fullscreen);
+EAPI EAPI_WEAK void efl_ui_win_fullscreen_set(Eo *obj, Eina_Bool fullscreen);
 
 /**
  * @brief The fullscreen state of a window.
@@ -615,7 +631,7 @@ EOAPI void efl_ui_win_fullscreen_set(Eo *obj, Eina_Bool fullscreen);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_fullscreen_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_fullscreen_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -631,7 +647,7 @@ EOAPI Eina_Bool efl_ui_win_fullscreen_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_sticky_set(Eo *obj, Eina_Bool sticky);
+EAPI EAPI_WEAK void efl_ui_win_sticky_set(Eo *obj, Eina_Bool sticky);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -649,7 +665,7 @@ EOAPI void efl_ui_win_sticky_set(Eo *obj, Eina_Bool sticky);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_sticky_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_sticky_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -664,7 +680,7 @@ EOAPI Eina_Bool efl_ui_win_sticky_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_urgent_set(Eo *obj, Efl_Ui_Win_Urgent_Mode urgent);
+EAPI EAPI_WEAK void efl_ui_win_urgent_set(Eo *obj, Efl_Ui_Win_Urgent_Mode urgent);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -679,7 +695,7 @@ EOAPI void efl_ui_win_urgent_set(Eo *obj, Efl_Ui_Win_Urgent_Mode urgent);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Efl_Ui_Win_Urgent_Mode efl_ui_win_urgent_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Win_Urgent_Mode efl_ui_win_urgent_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -693,7 +709,7 @@ EOAPI Efl_Ui_Win_Urgent_Mode efl_ui_win_urgent_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_modal_set(Eo *obj, Efl_Ui_Win_Modal_Mode modal);
+EAPI EAPI_WEAK void efl_ui_win_modal_set(Eo *obj, Efl_Ui_Win_Modal_Mode modal);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -708,7 +724,7 @@ EOAPI void efl_ui_win_modal_set(Eo *obj, Efl_Ui_Win_Modal_Mode modal);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Efl_Ui_Win_Modal_Mode efl_ui_win_modal_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Win_Modal_Mode efl_ui_win_modal_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -725,7 +741,7 @@ EOAPI Efl_Ui_Win_Modal_Mode efl_ui_win_modal_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_borderless_set(Eo *obj, Eina_Bool borderless);
+EAPI EAPI_WEAK void efl_ui_win_borderless_set(Eo *obj, Eina_Bool borderless);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -743,7 +759,7 @@ EOAPI void efl_ui_win_borderless_set(Eo *obj, Eina_Bool borderless);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_borderless_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_borderless_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -764,7 +780,7 @@ EOAPI Eina_Bool efl_ui_win_borderless_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_role_set(Eo *obj, const char *role);
+EAPI EAPI_WEAK void efl_ui_win_role_set(Eo *obj, const char *role);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -786,7 +802,7 @@ EOAPI void efl_ui_win_role_set(Eo *obj, const char *role);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_role_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_role_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -806,7 +822,7 @@ EOAPI const char *efl_ui_win_role_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_name_set(Eo *obj, const char *name);
+EAPI EAPI_WEAK void efl_ui_win_name_set(Eo *obj, const char *name);
 
 /**
  * @brief The window name.
@@ -826,7 +842,7 @@ EOAPI void efl_ui_win_name_set(Eo *obj, const char *name);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_name_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_name_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -848,7 +864,7 @@ EOAPI const char *efl_ui_win_name_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_type_set(Eo *obj, Efl_Ui_Win_Type type);
+EAPI EAPI_WEAK void efl_ui_win_type_set(Eo *obj, Efl_Ui_Win_Type type);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -872,7 +888,7 @@ EOAPI void efl_ui_win_type_set(Eo *obj, Efl_Ui_Win_Type type);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
+EAPI EAPI_WEAK Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -924,7 +940,7 @@ EOAPI Efl_Ui_Win_Type efl_ui_win_type_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
+EAPI EAPI_WEAK void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -977,7 +993,7 @@ EOAPI void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_accel_preference_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_accel_preference_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -1001,7 +1017,7 @@ EOAPI const char *efl_ui_win_accel_preference_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_alpha_set(Eo *obj, Eina_Bool alpha);
+EAPI EAPI_WEAK void efl_ui_win_alpha_set(Eo *obj, Eina_Bool alpha);
 
 /**
  * @brief The alpha channel state of a window.
@@ -1024,7 +1040,7 @@ EOAPI void efl_ui_win_alpha_set(Eo *obj, Eina_Bool alpha);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_alpha_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_alpha_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -1048,7 +1064,7 @@ EOAPI Eina_Bool efl_ui_win_alpha_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_stack_id_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_stack_id_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1067,7 +1083,7 @@ EOAPI const char *efl_ui_win_stack_id_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_stack_master_id_set(Eo *obj, const char *id);
+EAPI EAPI_WEAK void efl_ui_win_stack_master_id_set(Eo *obj, const char *id);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1087,7 +1103,7 @@ EOAPI void efl_ui_win_stack_master_id_set(Eo *obj, const char *id);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_stack_master_id_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_stack_master_id_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1108,7 +1124,7 @@ EOAPI const char *efl_ui_win_stack_master_id_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_stack_base_set(Eo *obj, Eina_Bool base);
+EAPI EAPI_WEAK void efl_ui_win_stack_base_set(Eo *obj, Eina_Bool base);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1130,7 +1146,7 @@ EOAPI void efl_ui_win_stack_base_set(Eo *obj, Eina_Bool base);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_stack_base_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_stack_base_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1146,7 +1162,7 @@ EOAPI Eina_Bool efl_ui_win_stack_base_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_stack_pop_to(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_win_stack_pop_to(Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -1167,7 +1183,7 @@ EOAPI void efl_ui_win_stack_pop_to(Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_exit_on_all_windows_closed_set(const Eina_Value *exit_code);
+EAPI EAPI_WEAK void efl_ui_win_exit_on_all_windows_closed_set(const Eina_Value *exit_code);
 
 /**
  * @brief Enable quitting the main loop when all windows are closed.
@@ -1187,7 +1203,7 @@ EOAPI void efl_ui_win_exit_on_all_windows_closed_set(const Eina_Value *exit_code
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const Eina_Value *efl_ui_win_exit_on_all_windows_closed_get(void);
+EAPI EAPI_WEAK const Eina_Value *efl_ui_win_exit_on_all_windows_closed_get(void);
 
 /**
  * @brief Activate a window object.
@@ -1206,7 +1222,7 @@ EOAPI const Eina_Value *efl_ui_win_exit_on_all_windows_closed_get(void);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_activate(Eo *obj);
+EAPI EAPI_WEAK void efl_ui_win_activate(Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -1229,7 +1245,7 @@ EOAPI void efl_ui_win_activate(Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_center(Eo *obj, Eina_Bool h, Eina_Bool v);
+EAPI EAPI_WEAK void efl_ui_win_center(Eo *obj, Eina_Bool h, Eina_Bool v);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -1281,7 +1297,7 @@ EOAPI void efl_ui_win_center(Eo *obj, Eina_Bool h, Eina_Bool v);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_move_resize_start(Eo *obj, Efl_Ui_Win_Move_Resize_Mode mode);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_move_resize_start(Eo *obj, Efl_Ui_Win_Move_Resize_Mode mode);
 
 /**
  * @brief Base size for objects with sizing restrictions.
@@ -1301,7 +1317,7 @@ EOAPI Eina_Bool efl_ui_win_move_resize_start(Eo *obj, Efl_Ui_Win_Move_Resize_Mod
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_hint_base_set(Eo *obj, Eina_Size2D sz);
+EAPI EAPI_WEAK void efl_ui_win_hint_base_set(Eo *obj, Eina_Size2D sz);
 
 /**
  * @brief Base size for objects with sizing restrictions.
@@ -1322,7 +1338,7 @@ EOAPI void efl_ui_win_hint_base_set(Eo *obj, Eina_Size2D sz);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Size2D efl_ui_win_hint_base_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Size2D efl_ui_win_hint_base_get(const Eo *obj);
 
 /**
  * @brief Step size for objects with sizing restrictions.
@@ -1342,7 +1358,7 @@ EOAPI Eina_Size2D efl_ui_win_hint_base_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_hint_step_set(Eo *obj, Eina_Size2D sz);
+EAPI EAPI_WEAK void efl_ui_win_hint_step_set(Eo *obj, Eina_Size2D sz);
 
 /**
  * @brief Step size for objects with sizing restrictions.
@@ -1363,7 +1379,7 @@ EOAPI void efl_ui_win_hint_step_set(Eo *obj, Eina_Size2D sz);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Size2D efl_ui_win_hint_step_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Size2D efl_ui_win_hint_step_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -1392,7 +1408,7 @@ EOAPI Eina_Size2D efl_ui_win_hint_step_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Iterator *efl_ui_win_pointer_iterate(const Eo *obj, Eina_Bool hover);
+EAPI EAPI_WEAK Eina_Iterator *efl_ui_win_pointer_iterate(const Eo *obj, Eina_Bool hover) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1410,7 +1426,7 @@ EOAPI Eina_Iterator *efl_ui_win_pointer_iterate(const Eo *obj, Eina_Bool hover);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_rotation_set(Eo *obj, int rotation);
+EAPI EAPI_WEAK void efl_ui_win_rotation_set(Eo *obj, int rotation);
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
@@ -1429,7 +1445,7 @@ EOAPI void efl_ui_win_rotation_set(Eo *obj, int rotation);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI int efl_ui_win_rotation_get(const Eo *obj);
+EAPI EAPI_WEAK int efl_ui_win_rotation_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
@@ -1446,7 +1462,7 @@ EOAPI int efl_ui_win_rotation_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_focus_highlight_enabled_set(Eo *obj, Eina_Bool enabled);
+EAPI EAPI_WEAK void efl_ui_win_focus_highlight_enabled_set(Eo *obj, Eina_Bool enabled);
 
 /**
  * @brief Whether focus highlight is enabled or not on this window, regardless
@@ -1463,7 +1479,7 @@ EOAPI void efl_ui_win_focus_highlight_enabled_set(Eo *obj, Eina_Bool enabled);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_focus_highlight_enabled_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_focus_highlight_enabled_get(const Eo *obj);
 
 /**
  * @brief Control the widget focus highlight style.
@@ -1482,7 +1498,7 @@ EOAPI Eina_Bool efl_ui_win_focus_highlight_enabled_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_focus_highlight_style_set(Eo *obj, const char *style);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_focus_highlight_style_set(Eo *obj, const char *style);
 
 /**
  * @brief Control the widget focus highlight style.
@@ -1500,7 +1516,7 @@ EOAPI Eina_Bool efl_ui_win_focus_highlight_style_set(Eo *obj, const char *style)
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI const char *efl_ui_win_focus_highlight_style_get(const Eo *obj);
+EAPI EAPI_WEAK const char *efl_ui_win_focus_highlight_style_get(const Eo *obj);
 
 /**
  * @brief Whether focus highlight should animate or not.
@@ -1515,7 +1531,7 @@ EOAPI const char *efl_ui_win_focus_highlight_style_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI void efl_ui_win_focus_highlight_animate_set(Eo *obj, Eina_Bool animate);
+EAPI EAPI_WEAK void efl_ui_win_focus_highlight_animate_set(Eo *obj, Eina_Bool animate);
 
 /**
  * @brief Whether focus highlight should animate or not.
@@ -1531,9 +1547,9 @@ EOAPI void efl_ui_win_focus_highlight_animate_set(Eo *obj, Eina_Bool animate);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Bool efl_ui_win_focus_highlight_animate_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_win_focus_highlight_animate_get(const Eo *obj);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_DELETE_REQUEST;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_DELETE_REQUEST;
 
 /** Called when the window receives a delete request
  *
@@ -1543,7 +1559,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_DELETE_REQUEST;
  */
 #define EFL_UI_WIN_EVENT_DELETE_REQUEST (&(_EFL_UI_WIN_EVENT_DELETE_REQUEST))
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WITHDRAWN;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WITHDRAWN;
 
 /** Called when window is withdrawn
  *
@@ -1554,7 +1570,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WITHDRAWN;
 #define EFL_UI_WIN_EVENT_WITHDRAWN (&(_EFL_UI_WIN_EVENT_WITHDRAWN))
 #endif /* EFL_BETA_API_SUPPORT */
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MINIMIZED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MINIMIZED;
 
 /** Called when window is minimized
  *
@@ -1564,7 +1580,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MINIMIZED;
  */
 #define EFL_UI_WIN_EVENT_MINIMIZED (&(_EFL_UI_WIN_EVENT_MINIMIZED))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_NORMAL;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_NORMAL;
 
 /** Called when window is set to normal state
  *
@@ -1574,7 +1590,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_NORMAL;
  */
 #define EFL_UI_WIN_EVENT_NORMAL (&(_EFL_UI_WIN_EVENT_NORMAL))
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_STICK;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_STICK;
 
 /** Called when window is set as sticky
  *
@@ -1585,7 +1601,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_STICK;
 #define EFL_UI_WIN_EVENT_STICK (&(_EFL_UI_WIN_EVENT_STICK))
 #endif /* EFL_BETA_API_SUPPORT */
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNSTICK;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNSTICK;
 
 /** Called when window is no  longer set as sticky
  *
@@ -1596,7 +1612,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_UNSTICK;
 #define EFL_UI_WIN_EVENT_UNSTICK (&(_EFL_UI_WIN_EVENT_UNSTICK))
 #endif /* EFL_BETA_API_SUPPORT */
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_FULLSCREEN_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_FULLSCREEN_CHANGED;
 
 /** Called when window is set to or from fullscreen
  * @return Eina_Bool
@@ -1607,7 +1623,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_FULLSCREEN_CHANGED;
  */
 #define EFL_UI_WIN_EVENT_FULLSCREEN_CHANGED (&(_EFL_UI_WIN_EVENT_FULLSCREEN_CHANGED))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MAXIMIZED_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MAXIMIZED_CHANGED;
 
 /** Called when window is set to or from maximized
  * @return Eina_Bool
@@ -1618,7 +1634,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_MAXIMIZED_CHANGED;
  */
 #define EFL_UI_WIN_EVENT_MAXIMIZED_CHANGED (&(_EFL_UI_WIN_EVENT_MAXIMIZED_CHANGED))
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED;
 
 /** Called when indicator is property changed
  *
@@ -1629,7 +1645,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGE
 #define EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED (&(_EFL_UI_WIN_EVENT_INDICATOR_PROP_CHANGED))
 #endif /* EFL_BETA_API_SUPPORT */
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WIN_ROTATION_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WIN_ROTATION_CHANGED;
 
 /** Called when window rotation is changed, sends current rotation in degrees
  * @return int
@@ -1640,7 +1656,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WIN_ROTATION_CHANGED;
  */
 #define EFL_UI_WIN_EVENT_WIN_ROTATION_CHANGED (&(_EFL_UI_WIN_EVENT_WIN_ROTATION_CHANGED))
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PROFILE_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PROFILE_CHANGED;
 
 /** Called when profile is changed
  *
@@ -1651,7 +1667,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PROFILE_CHANGED;
 #define EFL_UI_WIN_EVENT_PROFILE_CHANGED (&(_EFL_UI_WIN_EVENT_PROFILE_CHANGED))
 #endif /* EFL_BETA_API_SUPPORT */
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED;
 
 /** Called when window manager rotation is changed
  *
@@ -1662,7 +1678,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED;
 #define EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED (&(_EFL_UI_WIN_EVENT_WM_ROTATION_CHANGED))
 #endif /* EFL_BETA_API_SUPPORT */
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_THEME_CHANGED;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_THEME_CHANGED;
 
 /** Called when theme is changed
  *
@@ -1672,7 +1688,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_THEME_CHANGED;
  */
 #define EFL_UI_WIN_EVENT_THEME_CHANGED (&(_EFL_UI_WIN_EVENT_THEME_CHANGED))
 #ifdef EFL_BETA_API_SUPPORT
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU;
 
 /** Called when elementary block menu action occurs
  *
@@ -1683,7 +1699,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU
 #define EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU (&(_EFL_UI_WIN_EVENT_ELM_ACTION_BLOCK_MENU))
 #endif /* EFL_BETA_API_SUPPORT */
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PAUSE;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PAUSE;
 
 /** Called when the window is not going be displayed for some time
  *
@@ -1693,7 +1709,7 @@ EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_PAUSE;
  */
 #define EFL_UI_WIN_EVENT_PAUSE (&(_EFL_UI_WIN_EVENT_PAUSE))
 
-EWAPI extern const Efl_Event_Description _EFL_UI_WIN_EVENT_RESUME;
+EAPI EAPI_WEAK extern const Efl_Event_Description _EFL_UI_WIN_EVENT_RESUME;
 
 /** Called before a window is rendered after a pause event
  *
