@@ -20,7 +20,7 @@ typedef Eo Elm_Entry_Part;
  */
 #define ELM_ENTRY_PART_CLASS elm_entry_part_class_get()
 
-EWAPI const Efl_Class *elm_entry_part_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *elm_entry_part_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
